/**
 * Template set for ui contrib.
 * @memberof module:apeman-tmpl-contrib-official
 * @namespace uiContrib
 */

"use strict";

var templating = require('apeman-commons-templating'),
    ci = require('apeman-tmpl-contrib-ci'),
    license = require('apeman-tmpl-contrib-license'),
    dotfiles = require('apeman-tmpl-contrib-dotfiles');

var _tmpl = require('./_tmpl');

/** @lends uiContrib */
module.exports = templating.budRenderer({
    'assets/src/module.js': {
        force: false,
        mode: '755',
        tmpl: _tmpl('ui-contrib/module.js.hbs')
    },
    'assets/test/karma.conf.js': {
        force: false,
        mode: '644',
        tmpl: _tmpl('ui-contrib/karma.conf.js.hbs')
    },
    'assets/test/{{pkg.name}}-test.js': {
        force: false,
        mode: '644',
        tmpl: _tmpl('ui-contrib/module-test.js.hbs')
    },
    'bower.json': ({
        force: true,
        mode: '444',
        tmpl: _tmpl('ui-contrib/bower.json.hbs')
    }),
    'ci/doc.js': {
        force: false,
        mode: '755',
        tmpl: _tmpl('ui-contrib/doc.js.hbs')
    },
    'ci/deploy.js': ci.deployJs({}),
    'ci/install.js': {
        force: false,
        mode: '755',
        tmpl: _tmpl('ui-contrib/install.js.hbs')
    },
    'ci/release.js': ci.releaseJs({}),
    'ci/register.sh': {
        force: false,
        mode: '755',
        tmpl: _tmpl('ui-contrib/register.sh.hbs')
    },
    'ci/report.js': ci.reportJs({}),
    'ci/cover.js': ci.coverJs({}),
    'ci/test.js': {
        force: false,
        mode: '755',
        tmpl: _tmpl('ui-contrib/test.js.hbs')
    },
    'ci/update.js': ci.updateJs({}),
    'doc/demo/datasource.js': {
        force: true,
        mode: '444',
        tmpl: _tmpl('ui-contrib/demo-datasource.js.hbs')
    },
    'doc/demo/index.js': {
        force: false,
        mode: '644',
        tmpl: _tmpl('ui-contrib/demo.js.hbs')
    },
    'doc/demo/index.css': {
        force: false,
        mode: '644',
        tmpl: _tmpl('ui-contrib/demo.css.hbs')
    },
    'doc/demo/index.html': {
        force: false,
        mode: '644',
        tmpl: _tmpl('ui-contrib/demo.html.hbs')
    },
    'doc/example-Apemanfile.js': {
        force: true,
        mode: '444',
        tmpl: _tmpl('ui-contrib/example-Apemanfile.js.hbs')
    },
    'doc/example-ui.js': {
        force: false,
        mode: '644',
        tmpl: _tmpl('ui-contrib/example-ui.js.hbs')
    },
    'index.js': {
        force: true,
        mode: '444',
        tmpl: _tmpl('ui-contrib/index.js.hbs')
    },
    'dist.js': {
        force: false,
        mode: '644',
        tmpl: _tmpl('ui-contrib/dist.js.hbs')
    },
    'dist_test.js': {
        force: false,
        mode: '644',
        tmpl: _tmpl('ui-contrib/dist_test.js.hbs')
    },
    '.gitignore': dotfiles.gitignore({}),
    '.signature.json': {
        force: false,
        mode: '644',
        tmpl: _tmpl('ui-contrib/signature.json.hbs')
    },
    'handybower.json': {
        force: false,
        mode: '644',
        tmpl: _tmpl('ui-contrib/handybower.json.hbs')
    },
    '.travis.yml': dotfiles.travisYml({
        before_script: [
            "gem install sass",
            "npm install karma -g",
            "npm install jasmine-core -g",
            "npm install karma-jasmine -g",
            "npm install karma-firefox-launcher -g",
            "export DISPLAY=:99.0",
            "sh -e /etc/init.d/xvfb start"
        ]
    }),
    '.codeclimate.yml': dotfiles.codeclimateYml({}),
    'LICENSE': license.mitLicense({}),
    'README.md': {
        force: true,
        mode: '444',
        tmpl: _tmpl('ui-contrib/README.md.hbs')
    }
});
